<?php

// PHP function to create a full HTML page with clickable
// continuation diagrams.
//
// Copyright (C) 2006-2008 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started in 2006 for DyToComp. Last revision: May 18, 2008.


require ("template.php");
require ("imgclick.php");

// Produces HTML code for clickable diagrams whose clicks transfer
// the user to a browser of Morse decompositions.
// Arguments (all arrays indexed from 0):
// $title - the title of this page
// $pagename - [unused]
// $images - array of images with the diagrams
// $heights - array of heights of diagrams in boxes
// $sizes - array of sizes of the boxes measured in pixels
// $addresses - array of target addresses (must end with '?',
//    coordinates will be appended)
// $descriptions - text descriptions to put after the images
// $warning - a warning to be displayed below the title of the page
// $imgperline - the number of images displayed per line
// $other - pairs of other attributes to hide in the form
// $titles - titles to appear above each image (include the <p></p> tags)
// Returns: Full HTML page with the clickable diagrams in it.
function diagrams ($title, $pagename, $images, $heights, $sizes, $addresses,
	$descriptions, $warning = '', $imgperline = 1, $other = array (),
	$titles = array ())
{
	$imghtml = "<p align=\"center\"><table align=\"center\" " .
		"cellspacing=\"0\" cellpadding=\"16\" border=\"0\">\n";
	for ($i = 0; $i < count ($images); $i += $imgperline)
	{
		$imghtml .= "<tr>\n";
		for ($imgcount = 0; ($imgcount < $imgperline) &&
			($i + $imgcount < count ($images)); ++ $imgcount)
		{
			$index = $i + $imgcount;
			$description = $descriptions [$index];
			$imgcode = img_click ($addresses [$index],
				$images [$index], $heights [$index],
				$sizes [$index], $other [$index]);
			$imghtml .= "<td align=\"center\">" .
				"${titles[$index]}<p>${imgcode}</p>" .
				"<p>${description}<br/>&nbsp;</p></td>\n";
		}
		$imghtml .= "</tr>\n";
	}
	$imghtml .= "</table></p>\n";

	$warnhtml = '';
	if (!empty ($warning))
	{
		$warnhtml = "<h2>$warning</h2>";
	}

	$html = html_begin ("Continuation of Morse Decopositions",
		"", "", false);
	$html .= <<< HTML
<h1 align="center">${title}</h1>
${warnhtml}
${imghtml}
HTML;
	$html .= html_end ();

	return $html;
}

?>