<?php

// PHP code for the main web page with the database paper supplementary data.
//
// Copyright (C) 2006-2008 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started in 2006. Last revision: May 18, 2008.


require ("template.php");
require ("imgclick.php");
require ("animation.php");


// prepare a clickable diagram for the 2D results
$imgpop2d = img_click ("leslie2.php?", "leslie2.png", 50, 8);
$imgbad2d = img_click ("leslie2.php?", "leslie2bad.png", 50, 8);

// prepare an animation of the layers of the 3D diagram
$animscript = anim_script ("leslie", numbernames ("slices/slice",
	".png", 0, 40), numbernames ("slices.php#layer", "", 0, 40),
	100, -1);
$animbody = anim_body ("leslie");
$animimg = anim_img ("leslie", "border=\"0\"");

// prepare a clickable diagram with the classes for the 3D results
$palette = img_click ("class.php", "palette.png", 5, 40,
	array ("width", "8"));

// prepare the beginning and the ending of the HTML page
$htmlbeg = html_begin ("Databases for the Global Dynamics " .
	"of Multiparameter Systems", $animscript, $animbody, true);
$htmlend = html_end ();

// prepare the entire HTML page
$html = <<< HTML
${htmlbeg}
<h1>Databases for the Global Dynamics of Multiparameter Systems</h1>

<p>This website contains supplementary data for the paper
<a href="http://www.pawelpilarczyk.com/preprint/2008data.pdf"
><em>Databases for the Global Dynamics
of Multiparameter Systems</em></a> by
<a href="http://www.math.kyoto-u.ac.jp/~arai/">Zin Arai</a>,
<a href="http://www.math.fau.edu/kalies/">William Kalies</a>,
<a href="http://www.math.kyoto-u.ac.jp/~kokubu/">Hiroshi Kokubu</a>,
<a href="http://www.math.rutgers.edu/~mischaik/">Konstantin Mischaikow</a>,
<a href="http://www.math.ryukoku.ac.jp/~oka/">Hiroe Oka</a>,
and <a href="http://www.pawelpilarczyk.com/">Pawe Pilarczyk</a>.</p>

<hr/>

<h2>Database for the Leslie Model
with <em>p</em>&nbsp;=&nbsp;0.7</h2>

<p align="center"><table align="center" cellspacing="0" cellpadding="8">
<tr>
<td align="center" width="50%" valign="top"><p>${imgpop2d}</p>
<p>Phenotype classes are indicated in different colors.</p></td>
<td align="center" width="50%" valign="top"><p>${imgbad2d}</p>
<p>Parameter boxes (indicated in red) for which there exists
at least one Morse set whose Conley index was not computed
because of lack of isolation.</p></td>
</tr><tr>
<td align="center" colspan="2">(Click each parameter box
to see the corresponding Conley-Morse graph and
the Morse decomposition.)</td>
</tr></table></p>

<hr>

<h2>Database for the Leslie Model with All Three Varying Parameters</h2>

<p align="center"><table align="center" cellspacing="0" cellpadding="8">
<tr>
<td align="center" valign="bottom"><p align="center">${animimg}</p></td>
<td align="center" valign="bottom"><p align="center"><a
href="leslie3cont.pdf"><img src="leslie3cont.png" border="0"/></a></p></td>
</tr><tr>
<td align="center" valign="top"><p align="center">An animation
of 40 slices of the 3D picture of phenotype classes.
(Hover mouse to pause the animation, click to browse
Conley-Morse graphs.)</p></td>
<td align="center" valign="top"><p align="center">A continuation graph
automatically generated from the result of computations
(Click to see a full-size PDF file.)</p></td>
</tr></table></p>

<p align="center"><table align="center" width="400"
cellspacing="0" cellpadding="8">
<tr>
<td align="center" valign="bottom"><p align="center">${palette}</p></td>
</tr><tr>
<td align="center" valign="top"><p align="center">The palette
of colors assigned to nontrivial phenotype classes
oredered by the number of boxes in the class.
(Click to see a description of the class.)</p></td>
</tr></table></p>

<p>Note: The Conley index of the origin has been set to what follows
from the analytical computations if it couldn't be computed automatically
(no isolation detected),
unless a bifurcation takes place for the range of parameters
covered by the box.</p>

<hr/>

<h2>Software for Computing Conley-Morse Graphs</h2>

<p>Efficient software for computing Conley-Morse graphs
in a distributed way in a multi-computer environment
which was used to construct the above-mentioned databases
can be downloaded free of charge from its author's website
<a href="http://www.pawelpilarczyk.com/cmgraphs/"
>http://www.pawelpilarczyk.com/cmgraphs/</a>.
The software is written in C++ and its source code is available
under the terms of GNU General Public License.
This code can be compiled by the GNU C++ compiler
in both Windows and Linux (a makefile is included).
Detailed documentation generated by Doxygen is also provided.</p>

<hr/>

<h2>Files for Offline Browsing</h2>

<p>This website can be copied for offline use by downloading
the compressed files listed below. Please, do not attempt to mirror
this website using <a href="http://www.httrack.com/">HTTrack</a>
or similar programs, because it contains
hundreds of thousands of pages automatically generated
by just a few PHP scripts, and at least twice that many pictures
which are unzipped and rescaled on-the-fly.
Browsing an offline copy of this website available below
requires the following software:
<ul>
<li>a HTTP server with PHP support (for example,
the <a href="http://httpd.apache.org/">Apache</a> server
with <a href="http://www.php.net/">PHP</a>),</li>
<li>the <tt>unzip</tt> program
(from the <a href="http://www.info-zip.org/">InfoZIP</a> package),</li>
<li>the <tt>dot</tt> program (from the
<a href="http://www.graphviz.org/">GraphVIZ</a> package),</li>
<li>the <tt>pngsmall</tt> program
(included in the software package listed in the previous section).</li>
</ul>
The files that can be download are as follows:
<ul>
<li><a href="zipped/phpcode.zip">phpcode.zip</a> (8.2 MB) &ndash;
the main PHP code of the website together with PNG
and other files</li>
<li><a href="zipped/leslie2c.zip">leslie2c.zip</a> (0.8 MB) &ndash;
text definitions of Conley-Morse graphs for the 2D computations</li>
<li><a href="zipped/leslie2p.zip">leslie2p.zip</a> (23 MB) &ndash;
png images of Morse decompositions for the 2D computations</li>
<li><a href="zipped/leslie3c.zip">leslie3c.zip</a> (86 MB) &ndash;
text definitions of Conley-Morse graphs for the 3D computations</li>
<li><a href="zipped/leslie3p.zip">leslie3p.zip</a> (1.9 GB!) &ndash;
png images of Morse decompositions for the 3D computations</li>
</ul>
The file <tt>phpcode.zip</tt> should be unpacked into an empty
directory, and the remaining files should be copied
into a subdirectory called "<tt>zipped</tt>" of the directory
into which <tt>phpcode.zip</tt> has been unzipped
(these files should not be decompressed).</p>

${htmlend}
HTML;

// output the HTML page
echo $html;

?>