<?php

// PHP functions which generate beginnings and endings of HTML pages.
//
// Copyright (C) 2006-2008 by Pawel Pilarczyk, http://www.pawelpilarczyk.com/
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started in 2006. Last revision: May 18, 2008.


// Generates HTML code for the beginning of a HTML page.
// $title - the title to be put in the header
// $headcode - additional tags or code to be added to the "head" section
// $bodycode - options to add to the "body" tag
// $indexing - should indexing of the page be allowed for the robots?
function html_begin ($title, $headcode, $bodycode, $indexing)
{
	// prepare a space after the word "body" in the <body> tag
	if (empty ($bodycode))
		$bodyspace = "";
	else
		$bodyspace = " ";

	// prepare a tag to keep indexing robots out
	if ($indexing)
		$norobots = "";
	else
		$norobots = "<meta name=\"robots\" " .
			"content=\"noindex,nofollow,noarchive\">\n";

	// return the HTML code for the beginning of the HTML page
	return <<< HTML
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-2">
<meta name="author" content="Pawel Pilarczyk">
${norobots}<title>${title}</title>
<link rel="stylesheet" media="screen" type="text/css" href="stylescr.css" />
<link rel="stylesheet" media="print" type="text/css" href="styleprt.css" />
${headcode}</head>
<body${bodyspace}${bodycode}>
<div id="text">
HTML;
} /* html_begin */

// Generates HTML code for the end of a HTML page.
function html_end ()
{
	// return the code for the end of the HTML page
	return <<< HTML
</div>
<hr/>
<div id="footer"><p>Copyright&nbsp;&copy;&nbsp;2006-2008
by <a href="http://www.pawelpilarczyk.com/">Pawe Pilarczyk</a>.
The contents of this page is published under the terms
of the <a href="http://www.gnu.org/copyleft/fdl.html">GNU Free
Documentation License</a>.<br/>
All trademarks, registered trademarks or brand names
are property of the respective holders and used in this document
for descriptive purposes only.</p></div>
</body>
</html>
HTML;
} /* html_end */

?>